NEP Python library
==================

NEP+ is a comprehensive software platform that facilitates the integration and design of interactive applications involving a spectrum of agents, whether physical (e.g., robots) or digital (e.g., digital twins).

The main functionality of NEP+ is to help and support in the design heterogeneous software architectures (i.e., complex applications composed of several modules developed over different programming languages, running on different operating systems, and performing different tasks).

Official website: https://enrique-coronado.gitbook.io/nep-docs/


